<?php

namespace NoccyLabs\Cups\Printer;

use Countable;
use Iterator;

class PrinterIterator implements Iterator, Countable
{

    private static $printcap_file = "/etc/printcap";

    private $printers = [];

    private $index = 0;

    public function __construct()
    {
        $this->printers = self::getPrintCapList();
    }

    public static function getPrintCapList(): array
    {
        $output = [];
        $printers = file(self::$printcap_file, FILE_SKIP_EMPTY_LINES|FILE_IGNORE_NEW_LINES);
        foreach ($printers as $printer) {
            if ($printer && $printer[0] != '#') {
                $output[] = $printer;
            }
        }
        return $output;
    }

    public function count()
    {
        return count($this->printers);
    }

    public function current()
    {
        if ($this->index >= count($this->printers)) {
            return null;
        }

        if (is_string($this->printers[$this->index])) {
            $this->printers[$this->index] = new Printer($this->printers[$this->index]);
        }

        return $this->printers[$this->index];
    }

    public function rewind()
    {
        $this->index = 0;
    }

    public function next()
    {
        $this->index++;
    }

    public function valid()
    {
        return ($this->index < count($this->printers));
    }

    public function key()
    {
        return $this->index;
    }

}